%global __provides_exclude_from %{_datadir}/%{name}/%{name}.py
%global __requires_exclude_from %{_datadir}/%{name}/%{name}.py

%define _texmf %(eval "echo `kpsewhich -expand-var '$TEXMFMAIN'`")

Name:           asymptote
Version:        3.01
Release:        %mkrel 1
Summary:        Powerful descriptive vector graphics language
Group:          Sciences/Other
License:        LGPLv3
URL:            https://asymptote.sourceforge.io/
Source0:        https://downloads.sourceforge.net/asymptote/%{name}-%{version}.src.tgz
Source1:        xasy.desktop
Patch0:         asymptote-2.84-settings.patch
ExcludeArch:    %{arm32}

BuildRequires:  cmake
BuildRequires:  bison
BuildRequires:  dvipdf
BuildRequires:  flex
BuildRequires:  pkgconfig(freeglut)
BuildRequires:  imagemagick
BuildRequires:  latex
BuildRequires:  libtool
BuildRequires:  boost-devel
BuildRequires:  libsigsegv-devel
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(eigen3)
BuildRequires:  pkgconfig(glm)
BuildRequires:  pkgconfig(gsl)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libtirpc)
BuildRequires:  pkgconfig(osmesa)
BuildRequires:  pkgconfig(bdw-gc)
BuildRequires:  pkgconfig(readline)
# requested for pyrcc5
BuildRequires:  python3-qt5-devel
BuildRequires:  texinfo-tex
Requires:       texlive
Requires:       librsvg
Requires(post): texlive
Requires(postun):texlive

%description
Asymptote is a powerful descriptive vector graphics language that provides
a natural coordinate-based framework for technical drawing. Labels and equations
are typeset with LaTeX, for high-quality PostScript output.

A major advantage of Asymptote over other graphics packages is that it is
a programming language, as opposed to just a graphics program.

%package gui
Summary:        GUI for Asymptote vector graphics language
Group:          Sciences/Other
Requires:       %{name} = %{version}-%{release}
Requires:       python3-cson
Requires:       python3-numpy
Requires:       python3-pillow-tk
Requires:       python3-qt5-core
Requires:       python3-qt5-gui
Requires:       python3-qt5-svg
Requires:       python3-qt5-widgets
Requires:       python3-tkinter
BuildArch:      noarch

%description gui
Asymptote is a powerful descriptive vector graphics language that provides
a natural coordinate-based framework for technical drawing. Labels and equations
are typeset with LaTeX, for high-quality PostScript output.

A major advantage of Asymptote over other graphics packages is that it is
a programming language, as opposed to just a graphics program.

This package contains "xasy", a GUI for Asymptote.

%prep
%autosetup -p1
sed -i -e 's/_LIB_/%{_lib}/' -e 's/_GS_MAJOR_/9/' settings.cc

%build
# disable offscreen rendering because it doesn't build with libOSMesa
# https://github.com/vectorgraphics/asymptote/issues/433
%configure \
    --enable-gc=system \
    --disable-offscreen \
    --with-latex=%{_texmf}/tex/latex \
    --with-context=%{_texmf}/tex/context

%make_build

%install
%make_install

# Fix info location
mv %{buildroot}%{_infodir}/%{name}/%{name}.info* %{buildroot}%{_infodir}

# Install desktop file
install -D -m644 %{SOURCE1} %{buildroot}%{_datadir}/applications/xasy.desktop

# Install icons
for size in 16x16 32x32 48x48; do
    mkdir -p %{buildroot}%{_iconsdir}/hicolor/$size/apps
    magick windows/asy.ico -resize $size %{buildroot}%{_iconsdir}/hicolor/$size/apps/asy.png
done

%post
texhash

%postun
texhash

%files
%doc %{_docdir}/%{name}
%{_bindir}/asy
%{_datadir}/%{name}
%exclude %{_datadir}/%{name}/GUI
%{_infodir}/asy-faq.info*
%{_infodir}/%{name}.info*
%{_mandir}/man1/asy.1*
%{_texmf}/tex/*/%{name}

%files gui
%{_bindir}/xasy
%{_datadir}/%{name}/GUI
%{_datadir}/applications/xasy.desktop
%{_iconsdir}/hicolor/*/apps/asy.png
%{_mandir}/man1/xasy.1*


%changelog
* Mon Feb 24 2025 daviddavid <daviddavid> 3.01-1.mga10
+ Revision: 2151817
- new version: 3.01

* Tue Feb 18 2025 daviddavid <daviddavid> 3.00-1.mga10
+ Revision: 2149330
- new version: 3.00

* Tue Feb 11 2025 daviddavid <daviddavid> 2.99-1.mga10
+ Revision: 2146883
- new version: 2.99

* Mon Feb 10 2025 daviddavid <daviddavid> 2.98-1.mga10
+ Revision: 2146736
- new version: 2.98
- new version: 2.97
+ wally <wally>
- rebuild for boost 1.87.0

* Sat Feb 08 2025 daviddavid <daviddavid> 2.96-2.mga10
+ Revision: 2146095
- exclude arm

* Sat Feb 08 2025 daviddavid <daviddavid> 2.96-1.mga10
+ Revision: 2146062
- new version: 2.96

* Mon Nov 25 2024 daviddavid <daviddavid> 2.95-1.mga10
+ Revision: 2118946
- new version: 2.95
- new version: 2.94
- new version: 2.93

* Wed Oct 09 2024 daviddavid <daviddavid> 2.92-1.mga10
+ Revision: 2104313
- new version: 2.92

* Sat Sep 14 2024 daviddavid <daviddavid> 2.91-1.mga10
+ Revision: 2096197
- new version: 2.91

* Fri Sep 13 2024 wally <wally> 2.90-2.mga10
+ Revision: 2095447
- rebuild for boost 1.86.0

* Thu Jun 27 2024 daviddavid <daviddavid> 2.90-1.mga10
+ Revision: 2077207
- new version: 2.90

* Wed Jun 19 2024 wally <wally> 2.89-2.mga10
+ Revision: 2075318
- rebuild for boost 1.85.0

* Mon Apr 01 2024 daviddavid <daviddavid> 2.89-1.mga10
+ Revision: 2053638
- new version 2.89
- disable offscreen rendering because it doesn't build with libOSMesa
  ° https://github.com/vectorgraphics/asymptote/issues/433

* Thu Mar 14 2024 daviddavid <daviddavid> 2.88-1.mga10
+ Revision: 2049891
- new version: 2.88

* Sun Mar 10 2024 daviddavid <daviddavid> 2.87-1.mga10
+ Revision: 2048976
- new version: 2.87

* Fri Jan 12 2024 wally <wally> 2.86-4.mga10
+ Revision: 2030517
- rebuild for boost 1.84.0

* Mon Dec 18 2023 papoteur <papoteur> 2.86-3.mga10
+ Revision: 2018939
- Mass Rebuild - Python 3.12

* Wed Sep 27 2023 wally <wally> 2.86-2.mga10
+ Revision: 1991414
- rebuild for boost 1.83.0

* Wed Sep 06 2023 daviddavid <daviddavid> 2.86-1.mga10
+ Revision: 1984699
- new version: 2.86

* Tue Feb 21 2023 ghibo <ghibo> 2.85-1.mga9
+ Revision: 1944539
- Update to release 2.85

* Tue Jan 24 2023 daviddavid <daviddavid> 2.84-1.mga9
+ Revision: 1935549
- new version: 2.84

* Fri Dec 30 2022 daviddavid <daviddavid> 2.83-3.mga9
+ Revision: 1928027
- rebuild for gsl 2.7.1 on armv7

* Thu Dec 29 2022 daviddavid <daviddavid> 2.83-2.mga9
+ Revision: 1927498
- rebuild for new gsl 2.7.1

* Fri Oct 07 2022 ghibo <ghibo> 2.83-1.mga9
+ Revision: 1895355
- Update to release 2.83

* Sat Aug 13 2022 neoclust <neoclust> 2.81-1.mga9
+ Revision: 1877329
- New version 2.81

* Thu Apr 28 2022 ghibo <ghibo> 2.80-1.mga9
+ Revision: 1854812
- Update to release 2.80

* Wed Apr 27 2022 ghibo <ghibo> 2.70-3.mga9
+ Revision: 1854685
- Add python3-cson, python3-numpy, python3-qt5-svg, python3-qt5-widgets to Requires for asymptote-gui (fixes bug #30340).
- Add python3-qt5-devel to BR.

* Fri Apr 01 2022 umeabot <umeabot> 2.70-2.mga9
+ Revision: 1839985
- Mageia 9 Mass Rebuild

* Mon Mar 15 2021 daviddavid <daviddavid> 2.70-1.mga9
+ Revision: 1703443
- new version: 2.70

* Tue Mar 02 2021 daviddavid <daviddavid> 2.69-1.mga9
+ Revision: 1695940
- new version: 2.69

* Thu Nov 26 2020 akien <akien> 2.68-1.mga8
+ Revision: 1649378
- Version 2.68

* Sun Oct 18 2020 akien <akien> 2.67-1.mga8
+ Revision: 1636688
- Version 2.67

* Thu Jul 09 2020 daviddavid <daviddavid> 2.66-1.mga8
+ Revision: 1603758
- new version: 2.66

* Fri Mar 27 2020 daviddavid <daviddavid> 2.65-1.mga8
+ Revision: 1560914
- new version: 2.65

* Thu Feb 20 2020 umeabot <umeabot> 2.62-2.mga8
+ Revision: 1547586
- Mageia 8 Mass Rebuild

* Sun Feb 09 2020 daviddavid <daviddavid> 2.62-1.mga8
+ Revision: 1488130
- new version: 2.62
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Jan 04 2020 luigiwalser <luigiwalser> 2.59-2.mga8
+ Revision: 1475930
- rebuild for readline

* Tue Oct 22 2019 daviddavid <daviddavid> 2.59-1.mga8
+ Revision: 1455096
- new version: 2.59

* Mon Sep 30 2019 daviddavid <daviddavid> 2.55-1.mga8
+ Revision: 1448432
- new version: 2.55

* Sat Sep 21 2019 wally <wally> 2.49-3.mga8
+ Revision: 1444499
- switch to python3

* Tue Aug 27 2019 daviddavid <daviddavid> 2.49-2.mga8
+ Revision: 1433720
- rebuild for new gsl 2.6

* Sun Apr 21 2019 akien <akien> 2.49-1.mga7
+ Revision: 1394551
- Version 2.49

* Tue Oct 02 2018 akien <akien> 2.47-1.mga7
+ Revision: 1314584
- Version 2.47

* Fri Sep 21 2018 umeabot <umeabot> 2.44-3.mga7
+ Revision: 1295002
- Mageia 7 Mass Rebuild

* Mon Sep 03 2018 tv <tv> 2.44-2.mga7
+ Revision: 1256646
- rely on filetriggers for info system (mga#23482)

* Mon May 14 2018 akien <akien> 2.44-1.mga7
+ Revision: 1229319
- Version 2.44

* Wed Dec 27 2017 wally <wally> 2.41-2.mga7
+ Revision: 1185637
- rebuild for new gsl

* Fri Mar 24 2017 akien <akien> 2.41-1.mga6
+ Revision: 1094686
- Version 2.41

* Sun Mar 05 2017 akien <akien> 2.40-1.mga6
+ Revision: 1088754
- Version 2.40

* Thu Jan 26 2017 akien <akien> 2.39-1.mga6
+ Revision: 1083483
- Version 2.39

* Sat Oct 08 2016 akien <akien> 2.38-1.mga6
+ Revision: 1059556
- Version 2.38

* Fri Apr 15 2016 akien <akien> 2.37-1.mga6
+ Revision: 1002742
- Version 2.37

* Tue Jan 26 2016 luigiwalser <luigiwalser> 2.35-2.mga6
+ Revision: 927698
- add patch from debian to fix build with gsl version 2
- rebuild for gsl

* Mon Jun 22 2015 akien <akien> 2.35-1.mga6
+ Revision: 839213
- Version 2.35

* Mon Feb 09 2015 akien <akien> 2.32-1.mga5
+ Revision: 814253
- asymptote-gui is noarch (python application)
- Version 2.32
- Add URL

* Wed Oct 15 2014 umeabot <umeabot> 2.24-4.mga5
+ Revision: 745795
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.24-3.mga5
+ Revision: 678010
- Mageia 5 Mass Rebuild
+ tv <tv>
- auto convert _exclude_files_from_autoreq

* Mon Oct 21 2013 umeabot <umeabot> 2.24-2.mga4
+ Revision: 541270
- Mageia 4 Mass Rebuild

* Fri Oct 11 2013 mitya <mitya> 2.24-1.mga4
+ Revision: 495432
- New version 2.24

* Fri Jan 11 2013 umeabot <umeabot> 2.21-2.mga3
+ Revision: 346485
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Dec 31 2012 mitya <mitya> 2.21-1.mga3
+ Revision: 336488
- Import Asymptote 2.21
- Created package structure for asymptote.

